@@ -1,5 +1,5 @@
 """aiml-utils is a python package for machine learning."""
 
-from .aiml.utils import{
+from .utils import{
 	add,
 }
\ No newline at end of file
